import unittest
from dotenv import load_dotenv
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        self.fc = FabricClientCore()

    def test_external_data_shares(self):
        
        fc = self.fc

        workspace_id = '63aa9e13-4912-4abe-9156-8a56e565b7a3'
        item_id = "148ef579-4a5d-4048-8a48-0a703c5e3a1a"

        recipient = {
            "userPrincipalName": "lisa4@fabrikam.com"
        }
        paths=["Files/to_share"]

        resp = fc.create_external_data_share(workspace_id, item_id, paths, recipient)
        self.assertIsNotNone(resp)
        self.assertIn('id', resp)


        get = fc.get_external_data_share(workspace_id, item_id, resp['id'])
        self.assertIsNotNone(get)
        self.assertEqual(get['id'], resp['id'])


        resp = fc.list_external_data_shares_in_item(workspace_id, item_id)
        self.assertGreater(len(resp), 0)

        data_share_ids = [ds['id'] for ds in resp]
        self.assertIn(get['id'], data_share_ids)


        resp = fc.revoke_external_data_share(workspace_id, item_id, get['id'])
        self.assertEqual(resp, 200)

        get2 = fc.get_external_data_share(workspace_id, item_id, get['id'])
        self.assertIsNotNone(get2)
        
        self.assertEqual(get['id'], get2['id'])
        self.assertEqual(get2['status'], 'Revoked')





import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()
    
    def test_gateways(self):

        fc = self.fc

        gateways = fc.list_gateways()

        for gw in gateways:
            if "publicKey" not in gw:
                fc.delete_gateway(gw['id'])
            if "publicKey" in gw:
                gw_id = gw['id']

        datetime_str = datetime.now().strftime("%Y-%m-%d-%H-%M-%S")
        display_name = 'fabricvnet-' + datetime_str
        gwr =  {'displayName': display_name,
                'capacityId': '339c785f-4489-46ae-a649-e049e7610479',
                'virtualNetworkAzureResource': {'virtualNetworkName': 'fabricvnet',
                'subnetName': 'default3',
                'resourceGroupName': 'fabricdemo',
                'subscriptionId': 'c77cc8fc-43bb-4d44-bdc5-6e20511ed2a8'},
                'inactivityMinutesBeforeSleep': 30,
                'numberOfMemberGateways': 2,
                'type': 'VirtualNetwork'}

        gw = fc.create_gateway(gwr)
        self.assertEqual(gw['displayName'], gwr['displayName'])

        gateways = fc.list_gateways()
        self.assertEqual(len(gateways), 2)

        gateways = [g for g in gateways if g['displayName'] == display_name]
        gw = gateways[0]

        ras = fc.list_gateway_role_assignments(gw['id'])
        self.assertEqual(len(ras), 1)

        principal = {"id" : "755f273c-98f8-408c-a886-691794938bd8",
                "type" : "ServicePrincipal"}

        new_ras = fc.add_gateway_role_assignment(gw['id'], principal, 'ConnectionCreator')
        self.assertIn("id", new_ras)
        self.assertEqual(2, len(fc.list_gateway_role_assignments(gw['id'])))

        new_ras = fc.update_gateway_role_assignment(gw['id'], new_ras['id'], 'Admin')
        self.assertEqual('Admin', new_ras['role'])

        new_ras_ = fc.get_gateway_role_assignment(gw['id'], new_ras['id'])
        self.assertEqual('Admin', new_ras_['role'])
        self.assertEqual(new_ras['id'], new_ras_['id'])

        resp_code = fc.delete_gateway_role_assignment(gw['id'], new_ras['id'])
        self.assertEqual(200, resp_code)
        self.assertEqual(1, len(fc.list_gateway_role_assignments(gw['id'])))

        

        gw_members = fc.list_gateway_members(gw_id)
        self.assertGreater(len(gw_members), 0)
        self.assertIn('id', gw_members[0])
        self.assertIn('displayName', gw_members[0])

        display_name_member = "surface_desktop" + datetime_str

        gw_member = fc.update_gateway_member(gateway_id = gw_id, gateway_member_id = gw_id, display_name=display_name_member, enabled=True)
        self.assertEqual(display_name_member, gw_member['displayName'])

        gw_ = fc.get_gateway(gw["id"])
        self.assertEqual(display_name, gw_['displayName'])

        gwr = {
            "type": "OnPremises",
            "displayName": display_name,
            "loadBalancingSetting": "Failover",
            "allowCloudConnectionRefresh": False,
            "allowCustomConnectors": False
            }

        gw_ = fc.update_gateway(gw_id, gwr)
        self.assertEqual(display_name, gw_['displayName'])

        resp_code = fc.delete_gateway(gw["id"])
        self.assertEqual(200, resp_code)

        self.assertEqual(len(fc.list_gateways()), 1)



import unittest
from dotenv import load_dotenv
from datetime import datetime
from time import sleep
from msfabricpysdkcore import FabricAzureClient

load_dotenv()


class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fac = FabricAzureClient()

    def test_azure_capacity(self):

        fac = self.fac

        subscription_id = "c77cc8fc-43bb-4d44-bdc5-6e20511ed2a8"
        resource_group_name = "fabricdemo"
        capacity_name = "westeuropeajrederer"
        capacity_name_new = "westeuropeajrederer" + datetime.now().strftime("%Y%m%d%H%M%S")

        resp = fac.check_name_availability(subscription_id, "westeurope", capacity_name_new)
        self.assertIn('nameAvailable', resp)
        self.assertEqual(resp['nameAvailable'], True)

        resp = fac.create_or_update_capacity(subscription_id, resource_group_name, capacity_name_new, 
                                            location="westeurope",
                                            properties_administration={"members": ['admin@MngEnvMCAP065039.onmicrosoft.com']},
                                            sku = "F2")
        self.assertIsNotNone(resp.name)
        self.assertEqual(resp.name, capacity_name_new)
        
        resp = fac.get_capacity(subscription_id, resource_group_name, capacity_name_new)
        self.assertIsNotNone(resp.name)
        self.assertEqual(resp.name, capacity_name_new)

        sku = resp.sku['name']

        sleep(60)
        
        resp = fac.delete_capacity(subscription_id, resource_group_name, capacity_name_new)
        self.assertEqual(resp.status_code, 202)


        resp = fac.list_by_resource_group(subscription_id, resource_group_name)
        cap_names = [cap["name"] for cap in resp]
        self.assertIn(capacity_name, cap_names)

        

        resp = fac.list_by_subscription(subscription_id)
        cap_names = [cap["name"] for cap in resp]
        self.assertIn(capacity_name, cap_names)


        resp = fac.list_skus(subscription_id)
        self.assertGreater(len(resp), 0, msg=f"No SKUs found: {resp}")


        resp = fac.list_skus_for_capacity(subscription_id, resource_group_name, capacity_name)
        self.assertGreater(len(resp), 0, msg=f"No SKUs found: {resp}")

        resp = fac.resume_capacity(subscription_id, resource_group_name, capacity_name)
        self.assertEqual(resp.status_code, 202)

        sleep(60)
        resp = fac.suspend_capacity(subscription_id, resource_group_name, capacity_name)
        self.assertEqual(resp.status_code, 202)
        sleep(60)

        if sku != "F4":
            resp = fac.update_capacity(subscription_id, resource_group_name, capacity_name, sku="F4")
            self.assertEqual(resp.sku["name"], "F4")
        else:
            resp = fac.update_capacity(subscription_id, resource_group_name, capacity_name, sku="F2")
            self.assertEqual(resp.sku["name"], "F2")



import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        self.item_name = "testitem" + datetime_str
        self.item_type = "Notebook"

    def test_semantic_models(self):
                    
        fc = self.fc
        workspace_id = '63aa9e13-4912-4abe-9156-8a56e565b7a3'
        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        semantic_model_name = "semanticmodel" + datetime_str

        semantic_model_w_content = fc.get_semantic_model(workspace_id, semantic_model_name="Table")

        definition = fc.get_semantic_model_definition(workspace_id, semantic_model_w_content.id)

        self.assertIsNotNone(definition)
        self.assertIn("definition", definition)
        definition = definition["definition"]
        semantic_model = fc.create_semantic_model(workspace_id, display_name=semantic_model_name, definition=definition)
        fc.update_semantic_model_definition(workspace_id, semantic_model.id, definition=definition)
        semantic_model = fc.get_semantic_model(workspace_id, semantic_model_id=semantic_model.id)
        self.assertEqual(semantic_model.display_name, semantic_model_name)
        self.assertIsNotNone(semantic_model.definition)
        
        semantic_models = fc.list_semantic_models(workspace_id)
        semantic_model_names = [sm.display_name for sm in semantic_models]
        self.assertGreater(len(semantic_models), 0)
        self.assertIn(semantic_model_name, semantic_model_names)

        sm = fc.get_semantic_model(workspace_id, semantic_model_name=semantic_model_name)
        self.assertIsNotNone(sm.id)
        self.assertEqual(sm.display_name, semantic_model_name)

        sm2 = fc.update_semantic_model(workspace_id, sm.id, display_name=f"u{semantic_model_name}", return_item=True)

        sm2 = fc.get_semantic_model(workspace_id, semantic_model_id=sm2.id)

        self.assertEqual(sm2.display_name, f"u{semantic_model_name}")

        status_code = fc.delete_semantic_model(workspace_id, sm.id)
        self.assertEqual(status_code, 200)


import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        self.item_name = "testitem" + datetime_str
        self.item_type = "Notebook"



    def test_eventhouses(self):
            
        fc = self.fc
        workspace_id = '63aa9e13-4912-4abe-9156-8a56e565b7a3'
        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        eventhouse_name = "evh" + datetime_str
        eventhouse1 = fc.create_eventhouse(workspace_id, display_name=eventhouse_name)
        self.assertEqual(eventhouse1.display_name, eventhouse_name)
        
        eventhouses = fc.list_eventhouses(workspace_id)
        eventhouse_names = [eh.display_name for eh in eventhouses]
        self.assertGreater(len(eventhouses), 0)
        self.assertIn(eventhouse_name, eventhouse_names)

        eh = fc.get_eventhouse(workspace_id, eventhouse_name=eventhouse_name)
        self.assertIsNotNone(eh.id)
        self.assertEqual(eh.display_name, eventhouse_name)
        new_display_name = eventhouse_name + "2"
        eh2 = fc.update_eventhouse(workspace_id, eh.id, display_name=new_display_name, return_item=True)

        definition = fc.get_eventhouse_definition(workspace_id, eventhouse_id=eh.id)
       
        self.assertIn("definition", definition)
        self.assertIn("parts", definition["definition"])
        self.assertGreaterEqual(len(definition["definition"]["parts"]), 2)

        response = fc.update_eventhouse_definition(workspace_id, eventhouse_id=eh.id, definition=definition["definition"])
        self.assertIn(response.status_code, [200, 202])

        eh = fc.get_eventhouse(workspace_id, eventhouse_id=eh.id)
        self.assertEqual(eh.display_name, new_display_name)
        self.assertEqual(eh.id, eh2.id)

        status_code = fc.delete_eventhouse(workspace_id, eh.id)
        self.assertEqual(status_code, 200)


import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        self.item_name = "testitem" + datetime_str
        self.item_type = "Notebook"
    
    def test_kql_querysets(self):

        fc = self.fc
        workspace_id = '63aa9e13-4912-4abe-9156-8a56e565b7a3'

        kql_queryset_name = "kqlqueryset12"
        kqlq_w_content = fc.get_kql_queryset(workspace_id, kql_queryset_name=kql_queryset_name)

        definition = fc.get_kql_queryset_definition(workspace_id, kqlq_w_content.id)
        self.assertIsNotNone(definition)
        self.assertIn("definition", definition)
        definition = definition["definition"]

        self.assertIsNotNone(kqlq_w_content.id)
        self.assertEqual(kqlq_w_content.display_name, kql_queryset_name)

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        kql_queryset_new = "kqlq" + datetime_str

        kqlq = fc.create_kql_queryset(workspace_id, definition=definition, display_name=kql_queryset_new)
        self.assertIsNotNone(kqlq.id)
        self.assertEqual(kqlq.display_name, kql_queryset_new)

        fc.update_kql_queryset_definition(workspace_id, kqlq.id, definition=definition)
        kqlq = fc.get_kql_queryset(workspace_id, kqlq.id)
        self.assertEqual(kqlq.display_name, kql_queryset_new)
        self.assertIsNotNone(kqlq.definition)

        kqlqs = fc.list_kql_querysets(workspace_id)
        kqlq_names = [kql.display_name for kql in kqlqs]
        self.assertGreater(len(kqlqs), 0)
        self.assertIn(kql_queryset_new, kqlq_names)

        kqlq = fc.get_kql_queryset(workspace_id, kql_queryset_name=kql_queryset_new)
        self.assertIsNotNone(kqlq.id)
        self.assertEqual(kqlq.display_name, kql_queryset_new)

        kqlq2 = fc.update_kql_queryset(workspace_id, kql_queryset_id=kqlq.id, display_name=f"{kql_queryset_new}2", return_item=True)

        kqlq = fc.get_kql_queryset(workspace_id, kql_queryset_id=kqlq.id)
        self.assertEqual(kqlq.display_name, f"{kql_queryset_new}2")
        self.assertEqual(kqlq.id, kqlq2.id)

        status_code = fc.delete_kql_queryset(workspace_id, kqlq.id)
        self.assertEqual(status_code, 200)


import unittest
from msfabricpysdkcore.coreapi import FabricClientCore
from datetime import datetime
from dotenv import load_dotenv

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()
        
    def test_git(self):

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        ws2_name = "git" + datetime_str
        self.fc.create_workspace(display_name=ws2_name)
        ws2 = self.fc.get_workspace_by_name(name=ws2_name)
        self.fc.assign_to_capacity(workspace_id=ws2.id, capacity_id="840a6c1e-5289-4094-bbc8-716daabaeeba")

        git_provider_details = {'organizationName': 'MngEnvMCAP065039',
                                'projectName': 'fabricdevops',
                                'gitProviderType': 'AzureDevOps',
                                'repositoryName': 'fabricdevops',
                                'branchName': 'main',
                                'directoryName': '/sdkdemoRTI'}

        status_code = self.fc.git_connect(workspace_id=ws2.id, git_provider_details=git_provider_details)

        self.assertEqual(status_code, 200)

        initialization_strategy = "PreferWorkspace"

        status_code = self.fc.git_initialize_connection(workspace_id=ws2.id, initialization_strategy=initialization_strategy)
        self.assertEqual(status_code, 200)

        connection_details = self.fc.git_get_connection(workspace_id=ws2.id)
        self.assertEqual(connection_details['gitConnectionState'], 'ConnectedAndInitialized')

        status = self.fc.git_get_status(workspace_id=ws2.id)
        self.assertTrue(len(status["changes"]) > 0)

        git_credentials = self.fc.get_my_git_credentials('e624ffea-990e-482c-b27c-4ed5adae73c6')
        self.assertTrue(git_credentials["source"] == "Automatic")

        status_code = self.fc.update_from_git(workspace_id=ws2.id, remote_commit_hash=status["remoteCommitHash"])

        self.assertEqual(status_code, 202)

        blubb_lakehouse = False
        for item in ws2.list_items():
            if item.type == "Lakehouse" and item.display_name == "blubb":
                blubb_lakehouse = True

        self.assertTrue(blubb_lakehouse)

        status_code = self.fc.git_disconnect(workspace_id=ws2.id)

        self.assertEqual(status_code, 200)

        ws2.delete()

if __name__ == "__main__":
    unittest.main()



import unittest
from msfabricpysdkcore.coreapi import FabricClientCore
from datetime import datetime
from dotenv import load_dotenv

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()
        self.workspace_id = '63aa9e13-4912-4abe-9156-8a56e565b7a3'

        self.lakehouse_target = "148ef579-4a5d-4048-8a48-0a703c5e3a1a"
        self.lakehouse_shortcut = "9d1e8b07-2fea-4fc5-872c-fb586d085149"

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        self.shortcutname = "shortcut" + datetime_str
        self.path_target = "Files/to_share"
        self.path_shortcut = "Files/shortcutfolder"

        self.target = {'oneLake': {'itemId': self.lakehouse_target,
                                   'path': self.path_target,        
                                   'workspaceId': self.workspace_id}}

    def test_shortcut_end_to_end(self):

        item = self.fc.create_shortcut(workspace_id=self.workspace_id,
                                       item_id=self.lakehouse_shortcut,
                                       path=self.path_shortcut,
                                       name=self.shortcutname,
                                       target=self.target)
        self.assertEqual(item.name, self.shortcutname)
        self.assertEqual(item.path, self.path_shortcut)
        self.assertIn("oneLake", item.target)

        item = self.fc.get_shortcut(workspace_id=self.workspace_id,
                                    item_id=self.lakehouse_shortcut,
                                    path=self.path_shortcut,
                                    name=self.shortcutname)
        self.assertEqual(item.name, self.shortcutname)
        self.assertEqual(item.path, self.path_shortcut)
        self.assertIn("oneLake", item.target)

        shortcuts = self.fc.list_shortcuts(workspace_id=self.workspace_id,
                                          item_id=self.lakehouse_shortcut, parent_path="Files")
        self.assertGreater(len(shortcuts), 0)


        status_code = self.fc.delete_shortcut(workspace_id=self.workspace_id,
                                             item_id=self.lakehouse_shortcut,
                                             path=self.path_shortcut,
                                             name=self.shortcutname)
        
        self.assertAlmostEqual(status_code, 200)

if __name__ == "__main__":
    unittest.main()


import unittest
from dotenv import load_dotenv
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        self.fc = FabricClientCore()

    def test_one_lake_data_access_security(self):

        fc = self.fc

        workspace_id = '63aa9e13-4912-4abe-9156-8a56e565b7a3'
        item_id = "148ef579-4a5d-4048-8a48-0a703c5e3a1a"

        resp = fc.list_data_access_roles(workspace_id=workspace_id, item_id=item_id)
        self.assertEqual(len(resp), 2)

        roles = resp[0]
        etag = resp[1]

        role1 = roles[1]

        self.assertIn('members', role1)
        self.assertIn('fabricItemMembers', role1['members'])
        self.assertGreater(len(role1['members']['fabricItemMembers']), 0)
        self.assertIn('itemAccess', role1['members']['fabricItemMembers'][0])

        item_access = role1["members"]["fabricItemMembers"][0]['itemAccess']
        item_access_old = list(item_access)
        if 'ReadAll' in item_access:
            item_access = ['Read', 'Write', 'Execute']
        else:
            item_access.append('ReadAll')

        role1["members"]["fabricItemMembers"][0]['itemAccess'] = item_access
        roles[1] = role1

        resp = fc.create_or_update_data_access_roles(workspace_id=workspace_id, 
                                                     item_id=item_id, 
                                                     data_access_roles=roles, 
                                                     etag_match={"If-Match":etag})


        resp = fc.list_data_access_roles(workspace_id=workspace_id, item_id=item_id)
        self.assertEqual(len(resp), 2)

        roles = resp[0]
        etag = resp[1]

        role1 = roles[1]

        self.assertIn('members', role1)
        self.assertIn('fabricItemMembers', role1['members'])
        self.assertGreater(len(role1['members']['fabricItemMembers']), 0)
        self.assertIn('itemAccess', role1['members']['fabricItemMembers'][0])

        item_access = role1["members"]["fabricItemMembers"][0]['itemAccess']
        self.assertNotEqual(item_access, item_access_old)


import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        self.fc = FabricClientCore()

    def test_environments_crudl(self):
        fc = self.fc
        workspace_id = '63aa9e13-4912-4abe-9156-8a56e565b7a3'
        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")

        env_name = "env" + datetime_str
        environment1 = fc.create_environment(workspace_id, display_name=env_name)
        self.assertEqual(environment1.display_name, env_name)

        environments = fc.list_environments(workspace_id)
        environment_names = [env.display_name for env in environments]
        self.assertGreater(len(environments), 0)
        self.assertIn(env_name, environment_names)

        env = fc.get_environment(workspace_id, environment_name=env_name)
        self.assertIsNotNone(env.id)
        self.assertEqual(env.display_name, env_name)
        new_name = env_name + "2"
        env2 = fc.update_environment(workspace_id, env.id, display_name=new_name, return_item=True)

        env = fc.get_environment(workspace_id, environment_id=env.id)
        self.assertEqual(env.display_name, new_name)
        self.assertEqual(env.id, env2.id)

        status_code = fc.delete_environment(workspace_id, env.id)
        self.assertEqual(status_code, 200)

    def test_environment_details(self):
        fc = FabricClientCore()
        workspace_id = '63aa9e13-4912-4abe-9156-8a56e565b7a3'
        environment_id = '5648be67-28fa-48b6-9d1f-3c87c3704d3c'
        published_settings = fc.get_published_settings(workspace_id=workspace_id, environment_id=environment_id)
        self.assertIsNotNone(published_settings)
        self.assertIn("instancePool", published_settings)
        self.assertIn("dynamicExecutorAllocation", published_settings)
        staging_settings = fc.get_staging_settings(workspace_id=workspace_id, environment_id=environment_id)
        self.assertIsNotNone(staging_settings)
        self.assertIn("instancePool", staging_settings)
        self.assertIn("dynamicExecutorAllocation", staging_settings)
        if staging_settings["driverCores"] == 8:
            driver_cores = 4
        else:
            driver_cores = 8
        updated_settings = fc.update_staging_settings(workspace_id=workspace_id, environment_id=environment_id, driver_cores=driver_cores)
        self.assertIn("instancePool", updated_settings)
        self.assertIn("dynamicExecutorAllocation", updated_settings)
        self.assertEqual(updated_settings["driverCores"], driver_cores)
        updated_settings = fc.get_staging_settings(workspace_id=workspace_id, environment_id=environment_id)
        self.assertIn("instancePool", updated_settings)
        self.assertIn("dynamicExecutorAllocation", updated_settings)
        self.assertEqual(updated_settings["driverCores"], driver_cores)


    def test_environment_spark_libraries(self):
        fc = self.fc
        workspace_id = '63aa9e13-4912-4abe-9156-8a56e565b7a3'
        environment_id = '5648be67-28fa-48b6-9d1f-3c87c3704d3c'

        resp = fc.get_published_libraries(workspace_id, environment_id)
        self.assertIn('customLibraries', resp)
        self.assertIn('wheelFiles', resp['customLibraries'])
        self.assertIn('msfabricpysdkcore-0.1.1-py3-none-any.whl', resp['customLibraries']['wheelFiles'])

        resp = fc.upload_staging_library(workspace_id, environment_id, 'dummy.whl')
        self.assertEqual(resp.status_code, 200)
        
        resp = fc.get_staging_libraries(workspace_id, environment_id)

        self.assertIn('customLibraries', resp)
        self.assertIn('wheelFiles', resp['customLibraries'])
        self.assertIn('dummy.whl', resp['customLibraries']['wheelFiles'])
        self.assertIn('staging.whl', resp['customLibraries']['wheelFiles'])

        
        resp = fc.publish_environment(workspace_id, environment_id)
        self.assertIn('publishDetails', resp)
        self.assertIn('state', resp['publishDetails'])
        self.assertEqual(resp['publishDetails']['state'].lower(), 'running')

        
        resp = fc.cancel_publish(workspace_id, environment_id)
        self.assertIn('publishDetails', resp)
        self.assertIn('state', resp['publishDetails'])
        self.assertEqual(resp['publishDetails']['state'].lower(), 'cancelled')

        resp = fc.delete_staging_library(workspace_id, environment_id, 'dummy.whl')
        self.assertEqual(resp.status_code, 200)

        resp = fc.get_staging_libraries(workspace_id, environment_id)

        self.assertIn('customLibraries', resp)
        self.assertIn('wheelFiles', resp['customLibraries'])
        self.assertNotIn('dummy.whl', resp['customLibraries']['wheelFiles'])
        self.assertIn('staging.whl', resp['customLibraries']['wheelFiles'])


        






import unittest
from dotenv import load_dotenv
from msfabricpysdkcore import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        self.fcc = FabricClientCore()
                  
    def test_folders(self):
        fcc = self.fcc

        workspace_id = "05bc5baa-ef02-4a31-ab20-158a478151d3"
        folder_id = "d4f3a9fb-6975-4f5c-9c6b-ca205280966f"

        folder = fcc.create_folder(workspace_id=workspace_id, display_name="sdk_sub_folder", parent_folder_id=folder_id)
        self.assertIsNotNone(folder)
        self.assertEqual(folder.display_name, "sdk_sub_folder")

        folder_ = fcc.get_folder(workspace_id=workspace_id, folder_id=folder.id)
        self.assertEqual(folder.id, folder_.id)

        folders = fcc.list_folders(workspace_id=workspace_id)
        folders = [folder for folder in folders if folder.display_name == "sdk_sub_folder"]
        self.assertGreater(len(folders), 0)

        folder = fcc.update_folder(workspace_id=workspace_id, folder_id=folder.id, display_name="sdk_sub_folder_updated")
        self.assertEqual(folder.display_name, "sdk_sub_folder_updated")

        folder = fcc.move_folder(workspace_id=workspace_id, folder_id=folder.id)
        self.assertEqual(folder.display_name, "sdk_sub_folder_updated")
        self.assertEqual(folder.parent_folder_id, "")

        folders = fcc.list_folders(workspace_id=workspace_id)

        for f in folders:
            if f.display_name != "sdk_folder":
                f.delete()

        folders = fcc.list_folders(workspace_id=workspace_id)
        self.assertEqual(len(folders), 1)












import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()
    
    def test_kql_database(self):

        fc = self.fc
        workspace_id = '63aa9e13-4912-4abe-9156-8a56e565b7a3'
        evenhouse_id = "f30ba76a-92c3-40d3-ad69-36db059c113d"

        creation_payload = {"databaseType" : "ReadWrite",
                            "parentEventhouseItemId" : evenhouse_id}

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        kqldb_name = "kql" + datetime_str
        kqldb = fc.create_kql_database(workspace_id = workspace_id, display_name=kqldb_name,
                                    creation_payload=creation_payload)
        self.assertEqual(kqldb.display_name, kqldb_name)

        kql_databases = fc.list_kql_databases(workspace_id)
        kql_database_names = [kqldb.display_name for kqldb in kql_databases]
        self.assertGreater(len(kql_databases), 0)
        self.assertIn(kqldb_name, kql_database_names)

        kqldb = fc.get_kql_database(workspace_id, kql_database_name=kqldb_name)
        self.assertIsNotNone(kqldb.id)
        self.assertEqual(kqldb.display_name, kqldb_name)
        
        new_name = kqldb_name+"2"
        kqldb2 = fc.update_kql_database(workspace_id, kqldb.id, display_name=new_name, return_item=True)

        kqldb = fc.get_kql_database(workspace_id, kql_database_id=kqldb.id)
        self.assertEqual(kqldb.display_name, new_name)
        self.assertEqual(kqldb.id, kqldb2.id)
        
        response = fc.update_kql_database_definition(workspace_id, kqldb.id, kqldb.definition)
        self.assertIn(response.status_code, [200, 202])

        definition = fc.get_kql_database_definition(workspace_id, kql_database_id=kqldb.id)
        self.assertIn("definition", definition)
        self.assertIn("parts", definition["definition"])
        self.assertGreaterEqual(len(definition["definition"]["parts"]), 3)

        status_code = fc.delete_kql_database(workspace_id, kqldb.id)
        self.assertEqual(status_code, 200)


import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

# class TestFabricClientCore(unittest.TestCase):

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()

   
    def test_mounted_adf(self):

        fc = self.fc
        workspace_id = '63aa9e13-4912-4abe-9156-8a56e565b7a3'

        definition = {'parts': [{'path': 'mountedDataFactory-content.json',
                                'payload': 'ewogICJkYXRhRmFjdG9yeVJlc291cmNlSWQiOiAiL3N1YnNjcmlwdGlvbnMvYzc3Y2M4ZmMtNDNiYi00ZDQ0LWJkYzUtNmUyMDUxMWVkMmE4L3Jlc291cmNlR3JvdXBzL2ZhYnJpY2RlbW8vcHJvdmlkZXJzL01pY3Jvc29mdC5EYXRhRmFjdG9yeS9mYWN0b3JpZXMvZmFicmljYWRmMjAyNTAzMDYiCn0=',
                                'payloadType': 'InlineBase64'},
                                {'path': '.platform',
                                'payload': 'ewogICIkc2NoZW1hIjogImh0dHBzOi8vZGV2ZWxvcGVyLm1pY3Jvc29mdC5jb20vanNvbi1zY2hlbWFzL2ZhYnJpYy9naXRJbnRlZ3JhdGlvbi9wbGF0Zm9ybVByb3BlcnRpZXMvMi4wLjAvc2NoZW1hLmpzb24iLAogICJtZXRhZGF0YSI6IHsKICAgICJ0eXBlIjogIk1vdW50ZWREYXRhRmFjdG9yeSIsCiAgICAiZGlzcGxheU5hbWUiOiAiZmFicmljYWRmMjAyNTAzMDYiCiAgfSwKICAiY29uZmlnIjogewogICAgInZlcnNpb24iOiAiMi4wIiwKICAgICJsb2dpY2FsSWQiOiAiMDAwMDAwMDAtMDAwMC0wMDAwLTAwMDAtMDAwMDAwMDAwMDAwIgogIH0KfQ==',
                                'payloadType': 'InlineBase64'}]}

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")

        mounted_adf_name = "mounted_adf" + datetime_str
        mounted_adf = fc.create_mounted_data_factory(workspace_id,
                                                     display_name=mounted_adf_name,
                                                     definition=definition)

        self.assertEqual(mounted_adf.display_name, mounted_adf_name)

        mounted_adfs = fc.list_mounted_data_factories(workspace_id)
        mounted_adf_names = [adf.display_name for adf in mounted_adfs]
        self.assertGreater(len(mounted_adfs), 0)
        self.assertIn(mounted_adf_name, mounted_adf_names)

        adf = fc.get_mounted_data_factory(workspace_id, mounted_data_factory_name=mounted_adf_name)
        self.assertIsNotNone(adf.id)
        self.assertEqual(adf.display_name, mounted_adf_name)

        adf2 = fc.update_mounted_data_factory(workspace_id, adf.id, display_name=f"{mounted_adf_name}2", return_item=True)

        adf = fc.get_mounted_data_factory(workspace_id, mounted_data_factory_id=adf.id)
        self.assertEqual(adf.display_name, f"{mounted_adf_name}2")
        self.assertEqual(adf.id, adf2.id)

        response = fc.update_mounted_data_factory_definition(workspace_id, mounted_data_factory_id=adf.id, definition=adf.definition)
        self.assertIn(response.status_code, [200, 202])

        definition = fc.get_mounted_data_factory_definition(workspace_id, mounted_data_factory_id=adf.id)
        self.assertIn("definition", definition)
        self.assertIn("parts", definition["definition"])
        self.assertGreaterEqual(len(definition["definition"]["parts"]), 2)

        status_code = fc.delete_mounted_data_factory(workspace_id, adf.id)
        self.assertEqual(status_code, 200)



import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()

    def test_eventstreams(self):

        fc = self.fc
        workspace_id = '63aa9e13-4912-4abe-9156-8a56e565b7a3'

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        es_name = "es" + datetime_str

        eventstream = fc.create_eventstream(workspace_id, display_name=es_name)
        self.assertEqual(eventstream.display_name, es_name)

        eventstreams = fc.list_eventstreams(workspace_id)
        eventstream_names = [es.display_name for es in eventstreams]
        self.assertGreater(len(eventstreams), 0)
        self.assertIn(es_name, eventstream_names)

        
        es = fc.get_eventstream(workspace_id, eventstream_name=es_name)
        self.assertIsNotNone(es.id)
        self.assertEqual(es.display_name, es_name)

        es2 = fc.update_eventstream(workspace_id, es.id, display_name=f"{es_name}2", return_item=True)

        es = fc.get_eventstream(workspace_id, eventstream_id=es.id)
        self.assertEqual(es.display_name, f"{es_name}2")
        self.assertEqual(es.id, es2.id)

        response = fc.update_eventstream_definition(workspace_id, eventstream_id=es.id, definition=es.definition)
        self.assertIn(response.status_code, [200, 202])

        definition = fc.get_eventstream_definition(workspace_id, eventstream_id=es.id)
        self.assertIn("definition", definition)
        self.assertIn("parts", definition["definition"])
        self.assertGreaterEqual(len(definition["definition"]["parts"]), 3)

        status_code = fc.delete_eventstream(workspace_id, es.id)
        self.assertEqual(status_code, 200)



import unittest
from dotenv import load_dotenv
from msfabricpysdkcore import FabricClientCore
from datetime import datetime
load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        self.fcc = FabricClientCore()
                  
    def test_variable_librarys(self):
        fcc = self.fcc

        workspace_id = "05bc5baa-ef02-4a31-ab20-158a478151d3"
        item_id = "0812f094-1a5a-4b2a-aba2-e764af2709ec"

        variable_librarys = fcc.list_variable_libraries(workspace_id=workspace_id)
        for variable_library in variable_librarys:
            if variable_library.id != item_id:
                resp = fcc.delete_variable_library(workspace_id=workspace_id, variable_library_id=variable_library.id)
                self.assertEqual(resp, 200)

        variable_library_definition = fcc.get_variable_library_definition(workspace_id=workspace_id, variable_library_id=item_id)
        self.assertIn("definition", variable_library_definition)
        definition = variable_library_definition["definition"]

        date_str = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
        date_str = date_str.replace(" ", "T").replace(":", "").replace("-", "")
        date_str = f"variablelibrary{date_str}"

        variable_library_new = fcc.create_variable_library(workspace_id=workspace_id, display_name=date_str, definition=definition)

        self.assertEqual(variable_library_new.display_name, date_str)

        variable_library_get = fcc.get_variable_library(workspace_id=workspace_id, variable_library_id=variable_library_new.id)
        self.assertEqual(variable_library_get.display_name, date_str)

        variable_librarys = fcc.list_variable_libraries(workspace_id=workspace_id)
        self.assertEqual(len(variable_librarys), 2)

        date_str_updated = date_str + "_updated"
        variable_library_updated = fcc.update_variable_library(workspace_id=workspace_id, variable_library_id=variable_library_new.id, display_name=date_str_updated, return_item=True)
        self.assertEqual(variable_library_updated.display_name, date_str_updated)

        variable_library_updated = fcc.update_variable_library_definition(workspace_id=workspace_id, variable_library_id=variable_library_new.id, definition=definition)
        self.assertIn(variable_library_updated.status_code, [200, 202])

        for variable_library in variable_librarys:
            if variable_library.id != item_id:
                resp = fcc.delete_variable_library(workspace_id=workspace_id, variable_library_id=variable_library.id)
                self.assertEqual(resp, 200)










import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()

   
    def test_kql_dashboards(self):
        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        fc = self.fc
        workspace_id = '63aa9e13-4912-4abe-9156-8a56e565b7a3'

        kql_dash = fc.get_kql_dashboard(workspace_id, kql_dashboard_name='sampledashboard')
        kql_dash_orig_id = kql_dash.id


        kql_dash_name = "testdash" + datetime_str

        kql_dash = fc.create_kql_dashboard(display_name=kql_dash_name, workspace_id=workspace_id)
        self.assertEqual(kql_dash.display_name, kql_dash_name)

        definition_orig = fc.get_kql_dashboard_definition(workspace_id, kql_dash_orig_id)
        definition_orig = definition_orig["definition"]
        self.assertIsNotNone(definition_orig)

        definition = fc.update_kql_dashboard_definition(workspace_id, kql_dash.id, definition=definition_orig)

        self.assertIsNotNone(definition)

        kql_dashs = fc.list_kql_dashboards(workspace_id)

        kql_dash_names = [kqld.display_name for kqld in kql_dashs]
        self.assertGreater(len(kql_dashs), 0)
        self.assertIn(kql_dash_name, kql_dash_names)
        self.assertIn('sampledashboard', kql_dash_names)

        kql_dash2 = fc.get_kql_dashboard(workspace_id, kql_dashboard_name=kql_dash_name)
        self.assertIsNotNone(kql_dash2.id)
        self.assertEqual(kql_dash2.display_name, kql_dash_name)

        new_name = kql_dash_name+"2"
        kql_dash3 = fc.update_kql_dashboard(workspace_id, kql_dash.id, display_name=new_name, return_item=True)

        self.assertEqual(kql_dash3.display_name, new_name)
        self.assertEqual(kql_dash.id, kql_dash3.id)

        resp_code = fc.delete_kql_dashboard(workspace_id, kql_dash3.id)
        self.assertEqual(resp_code, 200)

        kql_dashs = fc.list_kql_dashboards(workspace_id)

        kql_dash_names = [kqld.display_name for kqld in kql_dashs]
        self.assertNotIn(kql_dash3.display_name, kql_dash_names)




import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

# class TestFabricClientCore(unittest.TestCase):

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()

   
    def test_sql_databases(self):

        fc = self.fc
        workspace_id = '63aa9e13-4912-4abe-9156-8a56e565b7a3'

        # datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")

        # sql_db = fc.create_sql_database(workspace_id, display_name="sqldb" + datetime_str)
        # self.assertEqual(sql_db.display_name, "sqldb" + datetime_str)

        # sql_dbs = fc.list_sql_databases(workspace_id)
        # sql_db_names = [db.display_name for db in sql_dbs]
        # self.assertGreater(len(sql_dbs), 0)
        # self.assertIn("sqldb" + datetime_str, sql_db_names)

        # db = fc.get_sql_database(workspace_id, sql_database_name="sqldb" + datetime_str)
        # self.assertIsNotNone(db.id)
        # self.assertEqual(db.display_name, "sqldb" + datetime_str)

        # db2 = fc.update_sql_database(workspace_id, db.id, display_name=f"sqldb{datetime_str}2", return_item=True)

        # db = fc.get_sql_database(workspace_id, sql_database_id=db.id)
        # self.assertEqual(db.display_name, f"sqldb{datetime_str}2")

        # status_code = fc.delete_sql_database(workspace_id, db.id)
        # self.assertEqual(status_code, 200)
        


import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()

    def test_connection(self):

        datetime_str = datetime.now().strftime("%Y%m%H%M%S")
        datetime_str
        fc = self.fc

        # display_name = "ContosoCloudConnection" + datetime_str

        # cr = {"connectivityType": "ShareableCloud",
        #     "displayName": display_name,
        #     "connectionDetails": {
        #         'type': "SQL",
        #         'creationMethod': 'SQL',
        #         "parameters": [
        #             {
        #                 "dataType": "Text",
        #                 "name": "server",
        #                 "value": "dfsdemo.database.windows.net"
        #             },
        #             {
        #                 "dataType": "Text",
        #                 "name": "database",
        #                 "value": "dfsdemo"
        #             }
        #             ]},
        #     'privacyLevel': 'Organizational',
        #     'credentialDetails': {'credentials':{'credentialType': 'Basic', 
        #                                         'userName': 'new_user', 
        #                                         'password': 'StrongPassword123!'},
        #                             'singleSignOnType': 'None',
        #                             'connectionEncryption': 'NotEncrypted',
        #                             'skipTestConnection': False}
        # }
            


        # connection = fc.create_connection(connection_request=cr)
        # self.assertIsNotNone(connection)
        # self.assertIn('id', connection)
        # self.assertIn('displayName', connection)
        # self.assertEqual(connection['displayName'], display_name)

        # connection2 = fc.get_connection(connection_name=display_name)
        # self.assertEqual(connection['id'], connection2['id'])


        # connections = fc.list_connections()
        # connection_names = [conn['displayName'] for conn in connections]
        # self.assertIn(display_name, connection_names)

        # id = connection['id']

        # role_assis = fc.list_connection_role_assignments(connection_id=id)
        # self.assertEqual(len(role_assis), 1)

        # principal = {"id" : "755f273c-98f8-408c-a886-691794938bd8",
        #             "type" : "ServicePrincipal"}

        # add_role_assi = fc.add_connection_role_assignment(connection_id=id, principal=principal, role='User')
        # self.assertIsNotNone(add_role_assi)
        # self.assertIn('id', add_role_assi)
        # role_assi_id = add_role_assi['id']

        # role_assis = fc.list_connection_role_assignments(connection_id=id)
        # self.assertEqual(len(role_assis), 2)

        # role_assi = fc.get_connection_role_assignment(connection_id=id,
        #                                               connection_role_assignment_id=role_assi_id)
        # self.assertEqual(role_assi['id'], role_assi_id)

        # role_assi = fc.update_connection_role_assignment(connection_id=id,
        #                                      connection_role_assignment_id=role_assi_id,
        #                                      role='UserWithReshare')
        # self.assertEqual(role_assi['role'], 'UserWithReshare')

        # status_code = fc.delete_connection_role_assignment(connection_id=id,
        #                                                    connection_role_assignment_id=role_assi_id)
        # self.assertEqual(status_code, 200)


        # cr = {
        # "connectivityType": "ShareableCloud",
        # "displayName": f"sqlserver{datetime_str}"
        # }

        # updated_connection = fc.update_connection(connection_id=id, connection_request=cr)
        # self.assertIsNotNone(updated_connection)


        # connection2 = fc.get_connection(connection_id=id)
        # self.assertEqual(connection['id'], connection2['id'])
        # self.assertEqual(connection2['displayName'], f"sqlserver{datetime_str}")

        # status_code = fc.delete_connection(connection_id=id)
        # self.assertEqual(status_code, 200)




import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        self.item_name = "testitem" + datetime_str
        self.item_type = "Notebook"

    
    def test_notebooks(self):
            
        fc = self.fc
        workspace_id = '63aa9e13-4912-4abe-9156-8a56e565b7a3'

        notebook_name = "notebook" + datetime.now().strftime("%Y%m%d%H%M%S")

        notebook_w_content = fc.get_notebook(workspace_id, notebook_name="HelloWorld")

        definition = fc.get_notebook_definition(workspace_id, notebook_w_content.id)
        
        self.assertIsNotNone(definition)
        self.assertIn("definition", definition)
        definition = definition["definition"]
        notebook = fc.create_notebook(workspace_id, definition=definition, display_name=notebook_name)
        fc.update_notebook_definition(workspace_id, notebook.id, definition=definition)
        notebook = fc.get_notebook(workspace_id, notebook_id=notebook.id)
        self.assertEqual(notebook.display_name, notebook_name)
        self.assertIsNotNone(notebook.definition)
        
        notebooks = fc.list_notebooks(workspace_id)
        notebook_names = [nb.display_name for nb in notebooks]
        self.assertGreater(len(notebooks), 0)
        self.assertIn(notebook_name, notebook_names)

        nb = fc.get_notebook(workspace_id, notebook_name=notebook_name)
        self.assertIsNotNone(nb.id)
        self.assertEqual(nb.display_name, notebook_name)

        nb2 = fc.update_notebook(workspace_id, notebook_id=nb.id, display_name=f"{notebook_name}2", return_item=True)

        nb = fc.get_notebook(workspace_id, notebook_id=nb.id)
        self.assertEqual(nb.display_name, f"{notebook_name}2")
        self.assertEqual(nb.id, nb2.id)

        status_code = fc.delete_notebook(workspace_id, nb.id)
        self.assertEqual(status_code, 200)


import unittest
from msfabricpysdkcore.coreapi import FabricClientCore
from dotenv import load_dotenv

load_dotenv()


class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        self.fc = FabricClientCore()
        


    def test_spark_workspace_custom_pools(self):
        fc = self.fc

        dep_pipes = fc.list_deployment_pipelines()

        self.assertGreater(len(dep_pipes), 0)

        self.assertIn("sdkpipe", [pipe.display_name for pipe in dep_pipes])

        for pipe in dep_pipes:
            if pipe.display_name == 'sdkpipe':
                pipe_id = pipe.id
                break

        pipe = fc.get_deployment_pipeline(pipe_id)

        self.assertEqual(pipe.display_name, 'sdkpipe')
        self.assertEqual(pipe.id, pipe_id)

        stages = fc.list_deployment_pipeline_stages(pipe_id)

        self.assertGreater(len(stages), 0)
        names = [stage.display_name for stage in stages]
        self.assertIn("Development", names)
        self.assertIn("Production", names)

        dev_stage = [stage for stage in stages if stage.display_name == "Development"][0]
        prod_stage = [stage for stage in stages if stage.display_name == "Production"][0]

        items = fc.list_deployment_pipeline_stages_items(deployment_pipeline_id=pipe_id, stage_id=dev_stage.id)
        
        self.assertGreater(len(items), 0)
        self.assertIn("cicdlakehouse", [item["itemDisplayName"] for item in items])
       
        items = [item for item in dev_stage.list_items() if item["itemDisplayName"] == 'cicdlakehouse']
        item = items[0]
        item = {"sourceItemId": item["itemId"],
                "itemType": item["itemType"]}
        items = [item]

        response = fc.deploy_stage_content(deployment_pipeline_id=pipe_id, source_stage_id=dev_stage.id,target_stage_id=prod_stage.id, items=items)

        self.assertEqual(response["status"], "Succeeded")

        






import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

# class TestFabricClientCore(unittest.TestCase):

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()

   
    def test_reflex(self):

        fc = self.fc
        workspace_id = '63aa9e13-4912-4abe-9156-8a56e565b7a3'

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")

        reflex_name = "reflex" + datetime_str

        reflex = fc.create_reflex(workspace_id, display_name=reflex_name)
        self.assertEqual(reflex.display_name, reflex_name)

        reflexes = fc.list_reflexes(workspace_id)
        reflex_names = [ref.display_name for ref in reflexes]
        self.assertGreater(len(reflexes), 0)
        self.assertIn(reflex_name, reflex_names)


        ref = fc.get_reflex(workspace_id, reflex_name=reflex_name)
        self.assertIsNotNone(ref.id)
        self.assertEqual(ref.display_name, reflex_name)

        ref2 = fc.update_reflex(workspace_id, ref.id, display_name=f"{reflex_name}2", return_item=True)

        ref = fc.get_reflex(workspace_id, reflex_id=ref.id)
        self.assertEqual(ref.display_name, f"{reflex_name}2")
        self.assertEqual(ref.id, ref2.id)

        response = fc.update_reflex_definition(workspace_id, reflex_id=ref.id, definition=ref.definition)
        self.assertIn(response.status_code, [200, 202])

        definition = fc.get_reflex_definition(workspace_id, reflex_id=ref.id)
        self.assertIn("definition", definition)
        self.assertIn("parts", definition["definition"])
        self.assertGreaterEqual(len(definition["definition"]["parts"]), 2)

        status_code = fc.delete_reflex(workspace_id, ref.id)
        self.assertEqual(status_code, 200)

